==> sawmill6.4b3_crypt_src.tar.gz: sawmill-6.4b3/S787c75233b93aa5e45c3f85d130bfbe7.cpp <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// then compilation!



















































 
#include "S5013dc63aece5960aaf85662d6e4defb.h"

#include "Sa7f564241028472364c4b422004927d3.h"

#include "S8e72db935b8a34033901bc251e070387.h"

#include "S033c90fd2ff4888be82b5e1092fc89eb.h"

#include "Sbfc9cb0c7c2fe6f4e17de2219c571a09.h"

#include "S02018c21aae4cfd793a8f80f191dec71.h"

#include "S3fe890ac3c9cdf3a851cca932627ecf4.h"

#include "S34ddd2a7515eccb177b2b41c0576524a.h"

#include "S0823eb7ea2b129b8fd70f3385bacf643.h"

#include "S18fff9cb5ec66ea1b3998c0c6f504bdd.h"
  void Sf2e35920bbc55965381fa1136c4bb795(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179, 
const char *Sd6e41fc5d1bcfead1db3b6dc05774971, const char *Sdf28a4c9f8a9c694f2ab61c3126d5a51) { S18fff9cb5ec66ea1b3998c0c6f504bdd(S749d2b576e15d77f0d14f186077e9ace) 
S972af69bf73f8ad23a446a346a6f0fff; S7a1e1302be0c6296d0828ba8b07c271d(&S972af69bf73f8ad23a446a346a6f0fff, 
Sd6e41fc5d1bcfead1db3b6dc05774971, ",");  S749d2b576e15d77f0d14f186077e9ace S0897acf49c7c1ea9f76efe59187aa046 
= S4d682ec4eed27c53849758bc13b6e179.S95cc64dd2825f9df13ec4ad683ecf339.Sbdbb50b900759955454e52a3e3a421fa; 
long S901555fb06e346cb065ceb9808dcfc25 = 25; long S25a7d6decc6dded4ed024e08a70650a3 = Sd0827c1f916039ab8191841de8297f59(S0897acf49c7c1ea9f76efe59187aa046.c_str(), 
':'); if (S25a7d6decc6dded4ed024e08a70650a3 == -1) S901555fb06e346cb065ceb9808dcfc25 = 25; else { S901555fb06e346cb065ceb9808dcfc25 
= atol(S0897acf49c7c1ea9f76efe59187aa046.c_str() + S25a7d6decc6dded4ed024e08a70650a3 + 1); S0897acf49c7c1ea9f76efe59187aa046 
= S0897acf49c7c1ea9f76efe59187aa046.substr(0, S25a7d6decc6dded4ed024e08a70650a3); }  Saca418ab700fd41fea0a83282df12687 
*socket; Saf6c0c3c714d1f5ab0d299b2cbf50060(socket = Sa7ad29e77b51199c1194b613ea1848dc(S4d682ec4eed27c53849758bc13b6e179, 
S0897acf49c7c1ea9f76efe59187aa046.c_str(), 25, false, false)); if (socket->Scb5e100e5a9a3e7f6d1fd97512215282) 
{ S88f99661138372f02e8c72cd959dee06(S4d682ec4eed27c53849758bc13b6e179.S95cc64dd2825f9df13ec4ad683ecf339.Sbdbb50b900759955454e52a3e3a421fa.c_str(), 
"{ERROR_SMTP_SERVER_REFUSED_CONNECTION}"); } S749d2b576e15d77f0d14f186077e9ace S1dccadfed7bcbb036c56a4afb97e906f; 
S749d2b576e15d77f0d14f186077e9ace Sd1fc8eaf36937be0c3ba8cfe0a2c1bfe;  Saf6c0c3c714d1f5ab0d299b2cbf50060(Sd1fc8eaf36937be0c3ba8cfe0a2c1bfe 
= S51a23dd5d91d21ec79abc2426759abb5(S4d682ec4eed27c53849758bc13b6e179, socket, "SMTP", true, "220", 
NULL, NULL));  Saf6c0c3c714d1f5ab0d299b2cbf50060(S1dccadfed7bcbb036c56a4afb97e906f = S749d2b576e15d77f0d14f186077e9ace() 
+ "HELO " + Se82e11797f03210214ed50e391d32dd0(S4d682ec4eed27c53849758bc13b6e179)); Saf6c0c3c714d1f5ab0d299b2cbf50060(socket->Saa232ed3abb535265477aeb8a1284765(S1dccadfed7bcbb036c56a4afb97e906f 
+ S8be07209d616d37ac0d2df76e79b3fa0)); Sa2ab70efbfabfbf410aade482c1f565b("Sent command: " << S1dccadfed7bcbb036c56a4afb97e906f 
<< endl); Saf6c0c3c714d1f5ab0d299b2cbf50060(Sd1fc8eaf36937be0c3ba8cfe0a2c1bfe = S51a23dd5d91d21ec79abc2426759abb5(S4d682ec4eed27c53849758bc13b6e179, 
socket, "SMTP", true, "250", NULL, NULL));  S1dccadfed7bcbb036c56a4afb97e906f = S749d2b576e15d77f0d14f186077e9ace() 
+ "MAIL FROM:<" + S4d682ec4eed27c53849758bc13b6e179.S95cc64dd2825f9df13ec4ad683ecf339.S62f51c0512689c2f0a68be7a859d90a4 
+ ">"; Saf6c0c3c714d1f5ab0d299b2cbf50060(socket->Saa232ed3abb535265477aeb8a1284765(S1dccadfed7bcbb036c56a4afb97e906f 
+ S8be07209d616d37ac0d2df76e79b3fa0)); Sa2ab70efbfabfbf410aade482c1f565b("Sent command: " << S1dccadfed7bcbb036c56a4afb97e906f 
<< endl); Saf6c0c3c714d1f5ab0d299b2cbf50060(Sd1fc8eaf36937be0c3ba8cfe0a2c1bfe = S51a23dd5d91d21ec79abc2426759abb5(S4d682ec4eed27c53849758bc13b6e179, 
socket, "SMTP", true, "250", NULL, NULL));  for (S18fff9cb5ec66ea1b3998c0c6f504bdd(S749d2b576e15d77f0d14f186077e9ace)::iterator 
S08c7b0daa33b1e5e86a230c1801254c9 = S972af69bf73f8ad23a446a346a6f0fff.begin(); S08c7b0daa33b1e5e86a230c1801254c9 
!= S972af69bf73f8ad23a446a346a6f0fff.end(); S08c7b0daa33b1e5e86a230c1801254c9++) { S1dccadfed7bcbb036c56a4afb97e906f 
= S749d2b576e15d77f0d14f186077e9ace() + "RCPT TO:<" + *S08c7b0daa33b1e5e86a230c1801254c9 + ">"; Saf6c0c3c714d1f5ab0d299b2cbf50060(socket->Saa232ed3abb535265477aeb8a1284765(S1dccadfed7bcbb036c56a4afb97e906f 
+ S8be07209d616d37ac0d2df76e79b3fa0)); Sa2ab70efbfabfbf410aade482c1f565b("Sent command: " << S1dccadfed7bcbb036c56a4afb97e906f 
<< endl); Saf6c0c3c714d1f5ab0d299b2cbf50060(Sd1fc8eaf36937be0c3ba8cfe0a2c1bfe = S51a23dd5d91d21ec79abc2426759abb5(S4d682ec4eed27c53849758bc13b6e179, 
socket, "SMTP", true, "250", NULL, NULL)); }  S1dccadfed7bcbb036c56a4afb97e906f = "DATA"; Saf6c0c3c714d1f5ab0d299b2cbf50060(socket->Saa232ed3abb535265477aeb8a1284765(S1dccadfed7bcbb036c56a4afb97e906f 
+ S8be07209d616d37ac0d2df76e79b3fa0)); Sa2ab70efbfabfbf410aade482c1f565b("Sent command: " << S1dccadfed7bcbb036c56a4afb97e906f 
<< endl); Saf6c0c3c714d1f5ab0d299b2cbf50060(Sd1fc8eaf36937be0c3ba8cfe0a2c1bfe = S51a23dd5d91d21ec79abc2426759abb5(S4d682ec4eed27c53849758bc13b6e179, 
socket, "SMTP", true, "354", NULL, NULL));  S749d2b576e15d77f0d14f186077e9ace S78e731027d8fd50ed642340b7c9a63b3 
= Sdf28a4c9f8a9c694f2ab61c3126d5a51; Saf6c0c3c714d1f5ab0d299b2cbf50060(S78e731027d8fd50ed642340b7c9a63b3.Sbdc6d6fb24f5283997e102146f1d9a10(S4d682ec4eed27c53849758bc13b6e179, 
"\n", "\r\n")); Saf6c0c3c714d1f5ab0d299b2cbf50060(S78e731027d8fd50ed642340b7c9a63b3.Sbdc6d6fb24f5283997e102146f1d9a10(S4d682ec4eed27c53849758bc13b6e179, 
"\r\r", "\r"));  Saf6c0c3c714d1f5ab0d299b2cbf50060(socket->Saa232ed3abb535265477aeb8a1284765(S78e731027d8fd50ed642340b7c9a63b3)); 
Saf6c0c3c714d1f5ab0d299b2cbf50060(socket->Saa232ed3abb535265477aeb8a1284765(".")); Saf6c0c3c714d1f5ab0d299b2cbf50060(socket->Saa232ed3abb535265477aeb8a1284765(S8be07209d616d37ac0d2df76e79b3fa0)); 
Saf6c0c3c714d1f5ab0d299b2cbf50060(Sd1fc8eaf36937be0c3ba8cfe0a2c1bfe = S51a23dd5d91d21ec79abc2426759abb5(S4d682ec4eed27c53849758bc13b6e179, 
socket, "SMTP", true, "250", NULL, NULL));  socket->Sd3d2e617335f08df83599665eef8a418(); }   void S15eb87c6fe7a77147d7a2348c5786ee2(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const S749d2b576e15d77f0d14f186077e9ace &S1f3d4e3ffc555681aaf3fd5abd9453fd, 
const S749d2b576e15d77f0d14f186077e9ace &Sa3ec4b334ddddcc6dd5a6e69a0cc90de) {  if (Seccd7eee4f711a07d3a1ef441ae79391(S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.S757477feaa10af28378ec948de43a908->S772a9297dbe0fc523d7a25bd303076bd(), 
("Content-Location: " + Sa3ec4b334ddddcc6dd5a6e69a0cc90de + "\n").c_str())) return;  Saf6c0c3c714d1f5ab0d299b2cbf50060(S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.S757477feaa10af28378ec948de43a908->S2c11af186543581d35c8291782e19c07("--==boundary-1\n")); 
Saf6c0c3c714d1f5ab0d299b2cbf50060(S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.S757477feaa10af28378ec948de43a908->S2c11af186543581d35c8291782e19c07("Content-Type: image/gif; name=\"" 
+ Sa3ec4b334ddddcc6dd5a6e69a0cc90de + "\"\n")); Saf6c0c3c714d1f5ab0d299b2cbf50060(S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.S757477feaa10af28378ec948de43a908->S2c11af186543581d35c8291782e19c07("Content-Location: " 
+ Sa3ec4b334ddddcc6dd5a6e69a0cc90de + "\n")); Saf6c0c3c714d1f5ab0d299b2cbf50060(S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.S757477feaa10af28378ec948de43a908->S2c11af186543581d35c8291782e19c07("Content-Description: " 
+ Sa3ec4b334ddddcc6dd5a6e69a0cc90de + "\n")); Saf6c0c3c714d1f5ab0d299b2cbf50060(S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.S757477feaa10af28378ec948de43a908->S2c11af186543581d35c8291782e19c07("Content-Id: <" 
+ Sb7680992561e3d4150a8f0d50aaf8dce(Sa3ec4b334ddddcc6dd5a6e69a0cc90de) + ">\n")); Saf6c0c3c714d1f5ab0d299b2cbf50060(S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.S757477feaa10af28378ec948de43a908->S2c11af186543581d35c8291782e19c07("Content-Transfer-Encoding: base64\n")); 
Saf6c0c3c714d1f5ab0d299b2cbf50060(S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.S757477feaa10af28378ec948de43a908->S2c11af186543581d35c8291782e19c07(("Content-Disposition: inline; filename=\"" 
+ Sa3ec4b334ddddcc6dd5a6e69a0cc90de + "\"\n").c_str())); Saf6c0c3c714d1f5ab0d299b2cbf50060(S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.S757477feaa10af28378ec948de43a908->S2c11af186543581d35c8291782e19c07("\n")); 
 FILE *S8c7dd922ad47494fc02c388e12c00eac = fopen(S1f3d4e3ffc555681aaf3fd5abd9453fd.c_str(), "rb"); if 
(!S8c7dd922ad47494fc02c388e12c00eac) { S88f99661138372f02e8c72cd959dee06(S1f3d4e3ffc555681aaf3fd5abd9453fd, 
"{ERROR_WRITE_FILE}"); }  Saf6c0c3c714d1f5ab0d299b2cbf50060(Sf29046e1fb6d7000e6a7e6328eaeb9e7(S4d682ec4eed27c53849758bc13b6e179, 
S8c7dd922ad47494fc02c388e12c00eac, S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.S757477feaa10af28378ec948de43a908)); 
 fclose(S8c7dd922ad47494fc02c388e12c00eac); }

==> sawmill6.4.5_crypt_src.tar.gz: sawmill-6.4.5/S787c75233b93aa5e45c3f85d130bfbe7.cpp <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// than compilation!



















































 
#include "S5013dc63aece5960aaf85662d6e4defb.h"

#include "Sa7f564241028472364c4b422004927d3.h"

#include "S8e72db935b8a34033901bc251e070387.h"

#include "S033c90fd2ff4888be82b5e1092fc89eb.h"

#include "Sbfc9cb0c7c2fe6f4e17de2219c571a09.h"

#include "S02018c21aae4cfd793a8f80f191dec71.h"

#include "S3fe890ac3c9cdf3a851cca932627ecf4.h"

#include "S34ddd2a7515eccb177b2b41c0576524a.h"

#include "S0823eb7ea2b129b8fd70f3385bacf643.h"

#include "S18fff9cb5ec66ea1b3998c0c6f504bdd.h"
  void Sf2e35920bbc55965381fa1136c4bb795(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179, 
const char *Sd6e41fc5d1bcfead1db3b6dc05774971, const char *Sdf28a4c9f8a9c694f2ab61c3126d5a51) { S18fff9cb5ec66ea1b3998c0c6f504bdd(S749d2b576e15d77f0d14f186077e9ace) 
S972af69bf73f8ad23a446a346a6f0fff; S7a1e1302be0c6296d0828ba8b07c271d(&S972af69bf73f8ad23a446a346a6f0fff, 
Sd6e41fc5d1bcfead1db3b6dc05774971, ",");  S749d2b576e15d77f0d14f186077e9ace S0897acf49c7c1ea9f76efe59187aa046 
= S4d682ec4eed27c53849758bc13b6e179.S95cc64dd2825f9df13ec4ad683ecf339.Sbdbb50b900759955454e52a3e3a421fa; 
long S901555fb06e346cb065ceb9808dcfc25 = 25; long S25a7d6decc6dded4ed024e08a70650a3 = Sd0827c1f916039ab8191841de8297f59(S0897acf49c7c1ea9f76efe59187aa046.c_str(), 
':'); if (S25a7d6decc6dded4ed024e08a70650a3 == -1) S901555fb06e346cb065ceb9808dcfc25 = 25; else { S901555fb06e346cb065ceb9808dcfc25 
= atol(S0897acf49c7c1ea9f76efe59187aa046.c_str() + S25a7d6decc6dded4ed024e08a70650a3 + 1); S0897acf49c7c1ea9f76efe59187aa046 
= S0897acf49c7c1ea9f76efe59187aa046.substr(0, S25a7d6decc6dded4ed024e08a70650a3); }  Saca418ab700fd41fea0a83282df12687 
*socket; Saf6c0c3c714d1f5ab0d299b2cbf50060(socket = Sa7ad29e77b51199c1194b613ea1848dc(S4d682ec4eed27c53849758bc13b6e179, 
S0897acf49c7c1ea9f76efe59187aa046.c_str(), S901555fb06e346cb065ceb9808dcfc25, false, false)); if (socket->Scb5e100e5a9a3e7f6d1fd97512215282) 
{ S88f99661138372f02e8c72cd959dee06(S4d682ec4eed27c53849758bc13b6e179.S95cc64dd2825f9df13ec4ad683ecf339.Sbdbb50b900759955454e52a3e3a421fa.c_str(), 
"{ERROR_SMTP_SERVER_REFUSED_CONNECTION}"); } S749d2b576e15d77f0d14f186077e9ace S1dccadfed7bcbb036c56a4afb97e906f; 
S749d2b576e15d77f0d14f186077e9ace Sd1fc8eaf36937be0c3ba8cfe0a2c1bfe;  Saf6c0c3c714d1f5ab0d299b2cbf50060(Sd1fc8eaf36937be0c3ba8cfe0a2c1bfe 
= S51a23dd5d91d21ec79abc2426759abb5(S4d682ec4eed27c53849758bc13b6e179, socket, "SMTP", true, "220", 
NULL, NULL));  Saf6c0c3c714d1f5ab0d299b2cbf50060(S1dccadfed7bcbb036c56a4afb97e906f = S749d2b576e15d77f0d14f186077e9ace() 
+ "HELO " + Se82e11797f03210214ed50e391d32dd0(S4d682ec4eed27c53849758bc13b6e179)); Saf6c0c3c714d1f5ab0d299b2cbf50060(socket->Saa232ed3abb535265477aeb8a1284765(S1dccadfed7bcbb036c56a4afb97e906f 
+ S8be07209d616d37ac0d2df76e79b3fa0)); Sa2ab70efbfabfbf410aade482c1f565b("Sent command: " << S1dccadfed7bcbb036c56a4afb97e906f 
<< endl); Saf6c0c3c714d1f5ab0d299b2cbf50060(Sd1fc8eaf36937be0c3ba8cfe0a2c1bfe = S51a23dd5d91d21ec79abc2426759abb5(S4d682ec4eed27c53849758bc13b6e179, 
socket, "SMTP", true, "250", NULL, NULL));  S1dccadfed7bcbb036c56a4afb97e906f = S749d2b576e15d77f0d14f186077e9ace() 
+ "MAIL FROM:<" + S4d682ec4eed27c53849758bc13b6e179.S95cc64dd2825f9df13ec4ad683ecf339.S62f51c0512689c2f0a68be7a859d90a4 
+ ">"; Saf6c0c3c714d1f5ab0d299b2cbf50060(socket->Saa232ed3abb535265477aeb8a1284765(S1dccadfed7bcbb036c56a4afb97e906f 
+ S8be07209d616d37ac0d2df76e79b3fa0)); Sa2ab70efbfabfbf410aade482c1f565b("Sent command: " << S1dccadfed7bcbb036c56a4afb97e906f 
<< endl); Saf6c0c3c714d1f5ab0d299b2cbf50060(Sd1fc8eaf36937be0c3ba8cfe0a2c1bfe = S51a23dd5d91d21ec79abc2426759abb5(S4d682ec4eed27c53849758bc13b6e179, 
socket, "SMTP", true, "250", NULL, NULL));  for (S18fff9cb5ec66ea1b3998c0c6f504bdd(S749d2b576e15d77f0d14f186077e9ace)::iterator 
S08c7b0daa33b1e5e86a230c1801254c9 = S972af69bf73f8ad23a446a346a6f0fff.begin(); S08c7b0daa33b1e5e86a230c1801254c9 
!= S972af69bf73f8ad23a446a346a6f0fff.end(); S08c7b0daa33b1e5e86a230c1801254c9++) { S1dccadfed7bcbb036c56a4afb97e906f 
= S749d2b576e15d77f0d14f186077e9ace() + "RCPT TO:<" + *S08c7b0daa33b1e5e86a230c1801254c9 + ">"; Saf6c0c3c714d1f5ab0d299b2cbf50060(socket->Saa232ed3abb535265477aeb8a1284765(S1dccadfed7bcbb036c56a4afb97e906f 
+ S8be07209d616d37ac0d2df76e79b3fa0)); Sa2ab70efbfabfbf410aade482c1f565b("Sent command: " << S1dccadfed7bcbb036c56a4afb97e906f 
<< endl); Saf6c0c3c714d1f5ab0d299b2cbf50060(Sd1fc8eaf36937be0c3ba8cfe0a2c1bfe = S51a23dd5d91d21ec79abc2426759abb5(S4d682ec4eed27c53849758bc13b6e179, 
socket, "SMTP", true, "250", NULL, NULL)); }  S1dccadfed7bcbb036c56a4afb97e906f = "DATA"; Saf6c0c3c714d1f5ab0d299b2cbf50060(socket->Saa232ed3abb535265477aeb8a1284765(S1dccadfed7bcbb036c56a4afb97e906f 
+ S8be07209d616d37ac0d2df76e79b3fa0)); Sa2ab70efbfabfbf410aade482c1f565b("Sent command: " << S1dccadfed7bcbb036c56a4afb97e906f 
<< endl); Saf6c0c3c714d1f5ab0d299b2cbf50060(Sd1fc8eaf36937be0c3ba8cfe0a2c1bfe = S51a23dd5d91d21ec79abc2426759abb5(S4d682ec4eed27c53849758bc13b6e179, 
socket, "SMTP", false, "354", NULL, NULL)); if (!S9d1a2cba952f9245c54397bbbf3e8183(Sd1fc8eaf36937be0c3ba8cfe0a2c1bfe.c_str(), 
"354")) { socket->Sd3d2e617335f08df83599665eef8a418(); S5f9c1850b588b053c5688b8461d7ace4("SMTP", Sd1fc8eaf36937be0c3ba8cfe0a2c1bfe, 
"{ERROR_UNEXPECTED_SERVER_RESPONSE}"); }  S749d2b576e15d77f0d14f186077e9ace S78e731027d8fd50ed642340b7c9a63b3 
= Sdf28a4c9f8a9c694f2ab61c3126d5a51; Saf6c0c3c714d1f5ab0d299b2cbf50060(S78e731027d8fd50ed642340b7c9a63b3.Sbdc6d6fb24f5283997e102146f1d9a10(S4d682ec4eed27c53849758bc13b6e179, 
"\n", "\r\n")); Saf6c0c3c714d1f5ab0d299b2cbf50060(S78e731027d8fd50ed642340b7c9a63b3.Sbdc6d6fb24f5283997e102146f1d9a10(S4d682ec4eed27c53849758bc13b6e179, 
"\r\r", "\r"));  Saf6c0c3c714d1f5ab0d299b2cbf50060(socket->Saa232ed3abb535265477aeb8a1284765(S78e731027d8fd50ed642340b7c9a63b3)); 
Saf6c0c3c714d1f5ab0d299b2cbf50060(socket->Saa232ed3abb535265477aeb8a1284765(".")); Saf6c0c3c714d1f5ab0d299b2cbf50060(socket->Saa232ed3abb535265477aeb8a1284765(S8be07209d616d37ac0d2df76e79b3fa0)); 
Saf6c0c3c714d1f5ab0d299b2cbf50060(Sd1fc8eaf36937be0c3ba8cfe0a2c1bfe = S51a23dd5d91d21ec79abc2426759abb5(S4d682ec4eed27c53849758bc13b6e179, 
socket, "SMTP", true, "250", NULL, NULL));  socket->Sd3d2e617335f08df83599665eef8a418(); }   void S15eb87c6fe7a77147d7a2348c5786ee2(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const S749d2b576e15d77f0d14f186077e9ace &S1f3d4e3ffc555681aaf3fd5abd9453fd, 
const S749d2b576e15d77f0d14f186077e9ace &Sa3ec4b334ddddcc6dd5a6e69a0cc90de) {  if (Seccd7eee4f711a07d3a1ef441ae79391(S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.S757477feaa10af28378ec948de43a908->S772a9297dbe0fc523d7a25bd303076bd(), 
("Content-Location: " + Sa3ec4b334ddddcc6dd5a6e69a0cc90de + "\n").c_str())) return;  Saf6c0c3c714d1f5ab0d299b2cbf50060(S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.S757477feaa10af28378ec948de43a908->S2c11af186543581d35c8291782e19c07("--==LogAnalysis-Boundary-Related\n")); 
Saf6c0c3c714d1f5ab0d299b2cbf50060(S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.S757477feaa10af28378ec948de43a908->S2c11af186543581d35c8291782e19c07("Content-Type: image/gif; name=\"" 
+ Sa3ec4b334ddddcc6dd5a6e69a0cc90de + "\"\n")); Saf6c0c3c714d1f5ab0d299b2cbf50060(S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.S757477feaa10af28378ec948de43a908->S2c11af186543581d35c8291782e19c07("Content-Location: " 
+ Sa3ec4b334ddddcc6dd5a6e69a0cc90de + "\n")); Saf6c0c3c714d1f5ab0d299b2cbf50060(S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.S757477feaa10af28378ec948de43a908->S2c11af186543581d35c8291782e19c07("Content-Description: " 
+ Sa3ec4b334ddddcc6dd5a6e69a0cc90de + "\n")); Saf6c0c3c714d1f5ab0d299b2cbf50060(S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.S757477feaa10af28378ec948de43a908->S2c11af186543581d35c8291782e19c07("Content-Id: <" 
+ Sb7680992561e3d4150a8f0d50aaf8dce(Sa3ec4b334ddddcc6dd5a6e69a0cc90de) + ">\n")); Saf6c0c3c714d1f5ab0d299b2cbf50060(S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.S757477feaa10af28378ec948de43a908->S2c11af186543581d35c8291782e19c07("Content-Transfer-Encoding: base64\n")); 
Saf6c0c3c714d1f5ab0d299b2cbf50060(S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.S757477feaa10af28378ec948de43a908->S2c11af186543581d35c8291782e19c07(("Content-Disposition: inline; filename=\"" 
+ Sa3ec4b334ddddcc6dd5a6e69a0cc90de + "\"\n").c_str())); Saf6c0c3c714d1f5ab0d299b2cbf50060(S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.S757477feaa10af28378ec948de43a908->S2c11af186543581d35c8291782e19c07("\n")); 
 FILE *S8c7dd922ad47494fc02c388e12c00eac = fopen(S1f3d4e3ffc555681aaf3fd5abd9453fd.c_str(), "rb"); if 
(!S8c7dd922ad47494fc02c388e12c00eac) { S88f99661138372f02e8c72cd959dee06(S1f3d4e3ffc555681aaf3fd5abd9453fd, 
"{ERROR_WRITE_FILE}"); }  Saf6c0c3c714d1f5ab0d299b2cbf50060(Sf29046e1fb6d7000e6a7e6328eaeb9e7(S4d682ec4eed27c53849758bc13b6e179, 
S8c7dd922ad47494fc02c388e12c00eac, S4d682ec4eed27c53849758bc13b6e179.S1d8d5e912302108b5e88c3e77fcad378.S757477feaa10af28378ec948de43a908)); 
 fclose(S8c7dd922ad47494fc02c388e12c00eac); }
